@@ -8,6 +8,7 @@ OC.L10N.register(
     "Add new property" : "Lisää uusi ominaisuus",
     "Choose property type" : "Valitse ominaisuuden tyyppi",
     "Upload a new picture" : "Lähetä uusi kuva",
+    "Image is too big (max 1MB)." : "Kuva on liian suuri (enintään 1 Mt).",
     "No contact selected" : "Yhteystietoa ei ole valittu",
     "Select a contact on the list to begin" : "Valitse yhteystieto luettelosta aloittaaksesi",
     "Loading" : "Ladataan",
@@ -21,9 +22,7 @@ OC.L10N.register(
     "Addressbook" : "Osoitekirja",
     "Groups" : "Ryhmät",
     "New contact" : "Uusi yhteystieto",
-    "The contact doesn't exists anymore on the server." : "Yhteystietoa ei ole enää olemassa tällä palvelimella.",
     "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
-    "failed" : "epäonnistui",
     "Select type" : "Valitse tyyppi",
     "Select Date" : "Valitse päivä",
     "Add contact in group" : "Lisää yhteystieto ryhmään",
@@ -62,6 +61,7 @@ OC.L10N.register(
     "Additional names" : "Lisänimet",
     "Prefix" : "Etuliite",
     "Suffix" : "Takaliite",
+    "Copy to full name" : "Kopioi koko nimeksi",
     "Notes" : "Huomiot",
     "Website" : "Verkkosivusto",
     "Federated Cloud ID" : "Federoidun pilven tunniste",
