@@ -23,14 +23,16 @@ OC.L10N.register(
     "Addressbook" : "Adressbok",
     "Groups" : "Grupper",
     "New contact" : "Ny kontakt",
-    "The contact doesn't exists anymore on the server." : "Kontakten finns inte längre på servern.",
+    "Syntax error. Cannot open the contact." : "Syntaxfel. Kan inte öppna kontakten.",
     "Importing {total} contacts into" : "Importerar {total} kontakter till",
+    "No errors" : "Inga fel",
     "Open your browser console for more details" : "Öppna din webbläsarkonsol för mer information",
-    "failed" : "misslyckades",
+    "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} felaktig kontakt","{failedCount} felaktiga kontakter"],
     "Select type" : "Välj typ",
     "Select Date" : "Välj datum",
     "Add contact in group" : "Lägg till kontakt i grupp",
     "No results" : "Inga resultat",
+    "Last modified" : "Senast ändrad",
     "Select option" : "Välj alternativ",
     "Copy link" : "Kopiera länk",
     "Copied" : "Kopierad",
@@ -45,6 +47,7 @@ OC.L10N.register(
     "Renaming of addressbook was not successful." : "Namnbyte av adressboken lyckades inte.",
     "Addressbook copied to clipboard" : "Adressbok kopierad till urklipp",
     "Addressbook was not copied to clipboard." : "Adressbok kopierades inte till urklipp",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delad med {num} enhet","Delad med {num} enheter"],
     "Share with users or groups" : "Dela med användare eller grupper",
     "No users or groups" : "Inga användare eller grupper",
     "can edit" : "kan redigera",
@@ -59,6 +62,7 @@ OC.L10N.register(
     "Last name" : "Efternamn",
     "Display name" : "Visningsnamn",
     "Sort by {sorting}" : "Sortera efter {sorting}",
+    "Not grouped" : "Inte grupperad",
     "Unable to create the contact." : "Kunde inte skapa kontakten.",
     "Contact not found" : "Kontakt ej hittad",
     "Nickname" : "Smeknamn",
@@ -66,6 +70,7 @@ OC.L10N.register(
     "Additional names" : "Mellannamn",
     "Prefix" : "Prefix",
     "Suffix" : "Suffix",
+    "Copy to full name" : "Kopiera till fullständigt namn",
     "Notes" : "Anteckningar",
     "Website" : "Webbplats",
     "Federated Cloud ID" : "Federerat Moln-ID",
@@ -81,6 +86,7 @@ OC.L10N.register(
     "Country" : "Land",
     "Birthday" : "Födelsedag",
     "Anniversary" : "Födelsedag",
+    "The date of marriage, or equivalent, of this contact" : "Äktenskapsdatum, eller motsvarande, för den här kontakten",
     "Date of death" : "Dödsdag",
     "Email" : "E-post",
     "Instant messaging" : "Snabbmeddelanden",
@@ -120,6 +126,9 @@ OC.L10N.register(
     "Gender" : "Kön",
     "Female" : "Kvinna",
     "Male" : "Man",
+    "None" : "Ingen",
+    "Unknown" : "Okänd",
+    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunde inte läsas","{failed} kontakter kunde inte läsas"],
     "An error occurred" : "Ett fel uppstod"
 },
 "nplurals=2; plural=(n != 1);");
