@@ -9,6 +9,7 @@ OC.L10N.register(
     "Add new property" : "新增属性",
     "Choose property type" : "选择属性类型",
     "Upload a new picture" : "上传一张新的图片",
+    "Image is too big (max 1MB)." : "图片过大(最大1MB)",
     "No contact selected" : "请选择联系人",
     "Select a contact on the list to begin" : "请先在列表里选择联系人",
     "Loading" : "载入中",
@@ -23,14 +24,16 @@ OC.L10N.register(
     "Addressbook" : "地址簿",
     "Groups" : "群组",
     "New contact" : "新建联系人",
-    "The contact doesn't exists anymore on the server." : "此联系人不再存在于此服务器上。",
+    "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
     "Importing {total} contacts into" : "导入 {total} 个联系人",
+    "No errors" : "没有错误",
     "Open your browser console for more details" : "打开浏览器控制台以获取更多详细信息",
-    "failed" : "失败了",
+    "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} 个有错误的联系人"],
     "Select type" : "选择类型",
     "Select Date" : "选择日期",
     "Add contact in group" : "添加联系人到群组",
     "No results" : "无结果",
+    "Last modified" : "上一次更改",
     "Select option" : "选择选项",
     "Copy link" : "复制链接",
     "Copied" : "已复制",
@@ -60,6 +63,7 @@ OC.L10N.register(
     "Last name" : "姓",
     "Display name" : "显示名称",
     "Sort by {sorting}" : "以 {sorting} 排序",
+    "Not grouped" : "未分组",
     "Unable to create the contact." : "未能成功创建联系人。",
     "Contact not found" : "未找到联系人",
     "Nickname" : "昵称",
@@ -67,6 +71,7 @@ OC.L10N.register(
     "Additional names" : "其他名称",
     "Prefix" : "前缀",
     "Suffix" : "后缀",
+    "Copy to full name" : "复制到全名",
     "Notes" : "说明",
     "Website" : "网站",
     "Federated Cloud ID" : "联合云 ID",
@@ -82,6 +87,7 @@ OC.L10N.register(
     "Country" : "国家",
     "Birthday" : "生日",
     "Anniversary" : "周年",
+    "The date of marriage, or equivalent, of this contact" : "此联系人的结婚纪念日，或与之相当的日期",
     "Date of death" : "去世日期",
     "Email" : "电子邮件",
     "Instant messaging" : "即时通讯",
